#
# spec file for package oniguruma
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lib_name libonig4
Name:           oniguruma
Version:        6.7.0
Release:        1.1
Summary:        Regex Library Supporting Different Character Encodings
License:        BSD-2-Clause
Group:          Development/Languages/C and C++
Url:            https://github.com/kkos/oniguruma
Source:         https://github.com/kkos/oniguruma/releases/download/v%{version}/onig-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

%package -n %{lib_name}
Summary:        Regex Library Supporting Different Character Encodings
Group:          System/Libraries

%description -n %{lib_name}
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

%package devel
Summary:        Regex Library Supporting Different Character Encodings - Development Files
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Obsoletes:      oniguruma <= 2.5.7

%description devel
Oniguruma is a regular expressions library.  The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

This package contains all necessary include files and libraries needed to
develop applications that require it.

%prep
%setup -q -n onig-%{version}
cp -rp sample/ examples

%build
export CFLAGS="%{optflags} -g"
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%{_libdir}/libonig.so.*

%files devel
%doc AUTHORS COPYING HISTORY index.html index_ja.html README
%doc doc/* examples/
%{_bindir}/onig-config
%{_includedir}/oniguruma.h
%{_includedir}/oniggnu.h
%{_includedir}/onigposix.h
%{_libdir}/libonig.so
%{_libdir}/pkgconfig/oniguruma.pc

%changelog
* Sat Dec 23 2017 avindra@opensuse.org
- Version 6.7.0
  - add ONIG_SYNTAX_ONIGURUMA (default syntax)
  - restructure StackType
  - implement subexp calls (?R), (?&name), (?-n), (?+n) for Perl
    syntax
  - use string pool of gperf for Unicode Property lookup function
  - fix an empty greedy regex and a word boundary (.*\b) fails
  - remove a stack type STK_POS
  - add a declaration of onig_end()
  - fix compilation failure in out-of-source build
  - [new] hexadecimal codepoint \uHHHH
- Version 6.6.1
  - fix definition of \X to (?>\O(?:\Y\O)*)
- Version 6.6.0
  - rename Absent clear to Range clear
  - [new] Extended Grapheme Cluster \X and boundary \y, \Y
  - fix: invalid index(ctype) value assigned to Unicode Block
    properties
  - --enable-crnl-as-line-terminator to be deprecated
  - [new] ASCII only mode options (?WDSP)
  - [new] ONIG_OPTION_XXXX_IS_ASCII  options
  - disable OP_CCLASS_NODE
  - [spec] Absent clear restore previous range value at backtrack
  - optimize for simple one char repetition in Absent expression
  - fix: invalid impl. for reluctant repetition in Absent expression
  - remove compile switch USE_NAMED_GROUP
  - Visual Studio 2005 compilation fixed
- cleanup with spec-cleaner
* Mon Aug  7 2017 mrueckert@suse.de
- Version 6.5.0
  - [new] support Absent clear (Absent functions)
  - abolish configure option: --enable-combination-explosion-check
  - [new] support Absent functions (?~...)
  - fix #65: SIZEOF_SIZE_T doesn't exist on certain architecutres
  - [new] support \O (true anychar)
  - [new] support \K (keep)
  - add new node type: NODE_GIMMICK
  - [new] support \N (no newline)
  - [new] support \R (general newline)
  - [new] support if-then-else syntax
  - [new] support backref validity checker
- Version 6.4.0
  - fix memory leaks
  - change encoding of doc/XXXX.ja from EUC-JP to UTF-8
  - update doc/RE, and doc/RE.ja
  - fix fatal bug of endless repeat check on Windows
  - PR #62 : add check for return values
  - [new] support call zero (\g{0})
  - [new] support relative call by positive number
  - [new] support relative back-reference by positive number
  - fix #60 : check value type
  - change output format for ONIG_DEBUG_COMPILE and
    ONIG_DEBUG_MATCH
- Version 6.3.0
  - fix #60 : invalid state(CCS_VALUE) in parse_char_class()
  - fix #59 : access to invalid address by reg->dmax value
  - fix invalid increment of start position in onig_scan()
  - fix #58 : access to invalid address by reg->dmin value
  - fix #57 : DATA_ENSURE() check must be before data access
  - fix #56 : return invalid result for codepoint 0xFFFFFFFF
  - [new] add \o{17777777777} syntax.
  - fix #55 : Byte value expressed in octal must be smaller than
    256
- Version 6.2.0
  - fix: size in xmemcpy in stack_double (PR #51)
  - Initialize return value
  - NEW API: add onig_set_capture_num_limit()
  - change MemNumType from short int to int
  - fix: [0-9-a] was not allowed as [0-9\-a]
  - fix: illegal capture after recursive call
  - fix: problem with optimization of \z
  - fix: .* optimization
  - Set a limit of parser recursion
  - fix; that warnings are not shown properly
  - fix: /[a-c#]+\W/ =~ "def#" fails when encoding is UTF-16/32
  - fix: /[\x{0}-X]/i doesn't match properly when UTF-16/32 is
    used.
- Version 6.1.3
  - fix: Syntax error: redirection unexpected (expecting word) #35
- Version 6.1.2
  - allow word bound, word begin and word end in look-behind.
  - add ONIG_OPTION_CHECK_VALIDITY_OF_STRING option.
  - fix use after free node.
  - fix memory leaks after parsing regexp error.
  - implement many of is_valid_mbc_string().
- Version 6.1.1
  - fix segfault /W.?{888}{888}{888}\x00/ (found by libfuzzer)
  - fix error unmatched close parenthesis for %%{(.*?)} #23
- Version 6.1.0
  - add contributed/libfuzzer-onig.cpp  (thanks hannob)
  - update LTVERSION 4:0:0
  - NEW API: onigenc_is_valid_mbc_string().
  - add is_valid_mbc_string() member into OnigEncodingType.
  - fix out of bounds read.
  - disable USE_INVALID_CODE_SCHEME.
  - doc/RE improved.
  - add onig_scan() into doc/API.
  - fix bug: Out of bounds read in onig_strcpy() #17
  - fix bug: infinite loop of backreference and group.
  - fix out of bounds read in mbc_to_code() #16
  - doc/RE refinements.
  - add onig_scan() (NEW API)
  - reimplement match stack allocation for case too many repeat
  - and too many captures in regexp.
  - number of captures <= 32767 for bytecode representation.
  - don't use int_map_backward for thread-safe.
  - fix case of enclosed option in look-behind.
  - fix ignore case in look-behind.
  - fix memory leak in onig_unicode_define_user_property()
  - declare variables at the top of scope.  (thanks nmaya)
- Version 6.0.0
  - add NEW API: onig_unicode_define_user_property()
  - update Unicode data to 8.0.0
  - change OnigCodePoint type to unsigned int.
  - add doc/UNICODE_PROPERTIES.
  - add error code ONIGERR_FAIL_TO_INITIALIZE.
  - add make_win64/32.bat.
  - fix bug of uninitialized regex_t value on error.
  - reimplement Unicode case folding.
  - update LTVERSION = 3.0.0
  - remove all THREAD_ macro.
  - add init member into OnigEncoding. (add onig_initialize())
  - remove state member of regex.
  - move source files into src/
  - rename configre.in to configure.ac.
  - fix memory leak. (thanks pigzang)
  - change mail address.
* Tue Mar  1 2016 mrueckert@suse.de
- remove ruby build requires. seems unused.
* Wed Oct 21 2015 i@marguerite.su
- update version 5.9.6
  * [impl] add onigenc_end_unicode().
  * [impl] add onig_add_end_call().
* Sat Sep  6 2014 i@marguerite.su
- update version 5.9.5
  * [impl] escape warnings for -Wall.
  * [impl] remove unused variable.
- changes in 5.9.4
  * [dist] add oniguruma.pc.in file
- changes in 5.9.3
  * fix print_tree ENCLOSE_OPTION bug
* Sat Aug 14 2010 gber@opensuse.org
- update to version 5.9.2:
  + many fixes
- cleanup:
  + split into liborig2 and oniguruma-devel subpackages
  + corrected license information
  + changed summary to conform with policy
* Fri Sep 29 2006 mrueckert@suse.de
- update to version 2.5.7:
  many fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 27 2005 mrueckert@suse.de
- Initial package of version 2.5.1
